--- SSRPoly Version 1.0
--- SSRPoly.sql Version 1.0
--- Copyright University of Queensland 2008
--- SSRPoly was produced by Nikki Appleby, Jacqueline Batley and David Edwards
--- For further information and contact details, please see README.txt

DROP TABLE IF EXISTS t_analysis;
CREATE TABLE t_analysis (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
	analysisName VARCHAR(200),
	readDate DATE,
	readStartTime TIME,
	readEndTime TIME,
	removeDate DATE,
	PRIMARY KEY (analysisID, clusterID),
	INDEX(analysisID),
	INDEX(clusterID)
);

DROP TABLE IF EXISTS t_sequence;
CREATE TABLE t_sequence (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
	seqID INTEGER UNSIGNED NOT NULL,
	seqName VARCHAR(150),
	seqDesc MEDIUMTEXT,
	seq MEDIUMTEXT,
	PRIMARY KEY (analysisID, clusterID, seqID),
	INDEX(analysisID),
	INDEX(clusterID),
	INDEX(seqID)
);

DROP TABLE IF EXISTS t_contigSeq;
CREATE TABLE t_contigSeq (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
	seqID INTEGER UNSIGNED NOT NULL,
	contigID INTEGER UNSIGNED NOT NULL,
	consensusPosn INTEGER,
	complement VARCHAR(1),
	qualClipStart INTEGER UNSIGNED,
	qualClipEnd INTEGER UNSIGNED,
	INDEX(analysisID),
	INDEX(clusterID),
	INDEX(seqID),
	INDEX(contigID)
);

DROP TABLE IF EXISTS t_contig;
CREATE TABLE t_contig (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
	contigID INTEGER UNSIGNED NOT NULL,
	contigName VARCHAR(100),
	isContig VARCHAR(1),
	totalSeqCount INTEGER UNSIGNED,
	consensusLen INTEGER UNSIGNED,
	consensusSeq MEDIUMTEXT,
	PRIMARY KEY (analysisID, clusterID, contigID),
	INDEX(analysisID),
	INDEX(clusterID),
	INDEX(contigID)
);

DROP TABLE IF EXISTS t_ssrSeq;
CREATE TABLE t_ssrSeq (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
  	seqID INTEGER UNSIGNED NOT NULL,
	seqSsrID INTEGER UNSIGNED NOT NULL,
  	ssrType VARCHAR(45),
  	ssrStart INTEGER UNSIGNED,
  	ssrEnd INTEGER UNSIGNED,
  	ssrLen INTEGER UNSIGNED,
  	score INTEGER UNSIGNED,
  	ssrSeq VARCHAR(150),
	ssrCtgStart INTEGER,
	motif VARCHAR(100),
	motifCount INTEGER UNSIGNED,
	contigID INTEGER UNSIGNED,
	groupID INTEGER UNSIGNED,
	consPosn INTEGER UNSIGNED,
	groupType VARCHAR(15),
	PRIMARY KEY (analysisID, clusterID, seqID, seqSsrID)
);

DROP TABLE IF EXISTS t_ssrSeq_ssr;
CREATE TABLE t_ssrSeq_ssr (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
  	seqID int(10) unsigned NOT NULL,
	ssrID INTEGER UNSIGNED,
	PRIMARY KEY (analysisID, clusterID, seqID, ssrID)
);


DROP TABLE IF EXISTS t_ssr;
CREATE TABLE t_ssr (
	analysisID INTEGER UNSIGNED NOT NULL,
	clusterID INTEGER UNSIGNED NOT NULL,
	contigID INTEGER UNSIGNED,
	ssrID INTEGER UNSIGNED,
	ssrStart INTEGER UNSIGNED,
	ssrEnd INTEGER UNSIGNED,
	ssrType VARCHAR(15),
	motif VARCHAR(100),
	motifCount INTEGER UNSIGNED,
	motifSeqCount VARCHAR(100),
	motifGroup VARCHAR(25),
	motifGroupName VARCHAR(10),
	PRIMARY KEY (analysisID, clusterID, contigID, ssrID)
);

